@@ -7,12 +7,18 @@ test_that("[ operator for incidence objects", {
   set.seed(123)
   dat <- as.integer(sample(-3:10, 50, replace=TRUE))
   x <- incidence(dat)
+  y <- incidence(dat + as.Date("2016-01-12"), 7L)
   
   x.sub1 <- x[c(3,5,7,8)]
   expect_equal_to_reference(x.sub1, file = "rds/x.sub1.rds")
   
   x.sub2 <- x[-c(5,1,2)]
   expect_equal_to_reference(x.sub2, file = "rds/x.sub2.rds")
+
+  y.sub1 <- y[1:2]
+  expect_equal_to_reference(y.sub1, file = "rds/y.sub1.rds")
+  expect_equal(y[1:2]$isoweeks, y$isoweeks[1:2])
+
 })
 
 
